Documentation
¶
Index ¶
- func CacheExpires(r *http.Response) time.Time
- func NewConfiguration(apiKeys ...*ncloud.APIKey) *ncloud.Configuration
- type APIClient
- type APIResponse
- type AccessControlGroup
- type ActivityLog
- type AdjustmentType
- type AutoScalingGroup
- type CommonCode
- type ConfigurationLog
- type CreateAutoScalingGroupRequest
- type CreateAutoScalingGroupResponse
- type CreateLaunchConfigurationRequest
- type CreateLaunchConfigurationResponse
- type DeleteAutoScalingGroupRequest
- type DeleteAutoScalingGroupResponse
- type DeleteAutoScalingLaunchConfigurationRequest
- type DeleteAutoScalingLaunchConfigurationResponse
- type DeletePolicyRequest
- type DeletePolicyResponse
- type DeleteScheduledActionRequest
- type DeleteScheduledActionResponse
- type ExecutePolicyRequest
- type ExecutePolicyResponse
- type GetAdjustmentTypeListRequest
- type GetAdjustmentTypeListResponse
- type GetAutoScalingActivityLogListRequest
- type GetAutoScalingActivityLogListResponse
- type GetAutoScalingConfigurationLogListRequest
- type GetAutoScalingConfigurationLogListResponse
- type GetAutoScalingGroupListRequest
- type GetAutoScalingGroupListResponse
- type GetAutoScalingPolicyListRequest
- type GetAutoScalingPolicyListResponse
- type GetLaunchConfigurationListRequest
- type GetLaunchConfigurationListResponse
- type GetScalingProcessTypeListRequest
- type GetScalingProcessTypeListResponse
- type GetScheduledActionListRequest
- type GetScheduledActionListResponse
- type InAutoScalingGroupServerInstance
- type LaunchConfiguration
- type LoadBalancerInstanceSummary
- type Process
- type PutScalingPolicyRequest
- type PutScalingPolicyResponse
- type PutScheduledUpdateGroupActionRequest
- type PutScheduledUpdateGroupActionResponse
- type ResumeProcessesRequest
- type ResumeProcessesResponse
- type ScalingPolicy
- type ScheduledUpdateGroupAction
- type SetDesiredCapacityRequest
- type SetDesiredCapacityResponse
- type SetServerInstanceHealthRequest
- type SetServerInstanceHealthResponse
- type SuspendProcessesRequest
- type SuspendProcessesResponse
- type SuspendedProcess
- type TerminateServerInstanceInAutoScalingGroupRequest
- type TerminateServerInstanceInAutoScalingGroupResponse
- type UpdateAutoScalingGroupRequest
- type UpdateAutoScalingGroupResponse
- type V2ApiService
- func (a *V2ApiService) CreateAutoScalingGroup(createAutoScalingGroupRequest *CreateAutoScalingGroupRequest) (*CreateAutoScalingGroupResponse, error)
- func (a *V2ApiService) CreateLaunchConfiguration(createLaunchConfigurationRequest *CreateLaunchConfigurationRequest) (*CreateLaunchConfigurationResponse, error)
- func (a *V2ApiService) DeleteAutoScalingGroup(deleteAutoScalingGroupRequest *DeleteAutoScalingGroupRequest) (*DeleteAutoScalingGroupResponse, error)
- func (a *V2ApiService) DeleteAutoScalingLaunchConfiguration(...) (*DeleteAutoScalingLaunchConfigurationRequest, error)
- func (a *V2ApiService) DeletePolicy(deletePolicyRequest *DeletePolicyRequest) (*DeletePolicyResponse, error)
- func (a *V2ApiService) DeleteScheduledAction(deleteScheduledActionRequest *DeleteScheduledActionRequest) (*DeleteScheduledActionResponse, error)
- func (a *V2ApiService) ExecutePolicy(executePolicyRequest *ExecutePolicyRequest) (*ExecutePolicyResponse, error)
- func (a *V2ApiService) GetAdjustmentTypeList(getAdjustmentTypeListRequest *GetAdjustmentTypeListRequest) (*GetAdjustmentTypeListResponse, error)
- func (a *V2ApiService) GetAutoScalingActivityLogList(getAutoScalingActivityLogListRequest *GetAutoScalingActivityLogListRequest) (*GetAutoScalingActivityLogListResponse, error)
- func (a *V2ApiService) GetAutoScalingConfigurationLogList(...) (*GetAutoScalingConfigurationLogListResponse, error)
- func (a *V2ApiService) GetAutoScalingGroupList(getAutoScalingGroupListRequest *GetAutoScalingGroupListRequest) (*GetAutoScalingGroupListResponse, error)
- func (a *V2ApiService) GetAutoScalingPolicyList(getAutoScalingPolicyListRequest *GetAutoScalingPolicyListRequest) (*GetAutoScalingPolicyListResponse, error)
- func (a *V2ApiService) GetLaunchConfigurationList(getLaunchConfigurationListRequest *GetLaunchConfigurationListRequest) (*GetLaunchConfigurationListResponse, error)
- func (a *V2ApiService) GetScalingProcessTypeList(getScalingProcessTypeListRequest *GetScalingProcessTypeListRequest) (*GetScalingProcessTypeListResponse, error)
- func (a *V2ApiService) GetScheduledActionList(getScheduledActionListRequest *GetScheduledActionListRequest) (*GetScheduledActionListResponse, error)
- func (a *V2ApiService) PutScalingPolicy(putScalingPolicyRequest *PutScalingPolicyRequest) (*PutScalingPolicyResponse, error)
- func (a *V2ApiService) PutScheduledUpdateGroupAction(putScheduledUpdateGroupActionRequest *PutScheduledUpdateGroupActionRequest) (*PutScheduledUpdateGroupActionResponse, error)
- func (a *V2ApiService) ResumeProcesses(resumeProcessesRequest *ResumeProcessesRequest) (*ResumeProcessesResponse, error)
- func (a *V2ApiService) SetDesiredCapacity(setDesiredCapacityRequest *SetDesiredCapacityRequest) (*SetDesiredCapacityResponse, error)
- func (a *V2ApiService) SetServerInstanceHealth(setServerInstanceHealthRequest *SetServerInstanceHealthRequest) (*SetServerInstanceHealthResponse, error)
- func (a *V2ApiService) SuspendProcesses(suspendProcessesRequest *SuspendProcessesRequest) (*SuspendProcessesResponse, error)
- func (a *V2ApiService) TerminateServerInstanceInAutoScalingGroup(...) (*TerminateServerInstanceInAutoScalingGroupResponse, error)
- func (a *V2ApiService) UpdateAutoScalingGroup(updateAutoScalingGroupRequest *UpdateAutoScalingGroupRequest) (*UpdateAutoScalingGroupResponse, error)
- type Zone
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CacheExpires ¶
CacheExpires helper function to determine remaining time before repeating a request.
func NewConfiguration ¶
func NewConfiguration(apiKeys ...*ncloud.APIKey) *ncloud.Configuration
Types ¶
type APIClient ¶
type APIClient struct {
// API Services
V2Api *V2ApiService
// contains filtered or unexported fields
}
APIClient manages communication with the autoscaling API v2021-01-21T11:17:47Z In most cases there should be only one, shared, APIClient.
func NewAPIClient ¶
func NewAPIClient(cfg *ncloud.Configuration) *APIClient
NewAPIClient creates a new API client. Requires a userAgent string describing your application. optionally a custom http.Client to allow for advanced features such as caching.
func (*APIClient) ChangeBasePath ¶
Change base path to allow switching to mocks
type APIResponse ¶
type APIResponse struct {
*http.Response `json:"-"`
Message string `json:"message,omitempty"`
// Operation is the name of the swagger operation.
Operation string `json:"operation,omitempty"`
// RequestURL is the request URL. This value is always available, even if the
// embedded *http.Response is nil.
RequestURL string `json:"url,omitempty"`
// Method is the HTTP method used for the request. This value is always
// available, even if the embedded *http.Response is nil.
Method string `json:"method,omitempty"`
// Payload holds the contents of the response body (which may be nil or empty).
// This is provided here as the raw response.Body() reader will have already
// been drained.
Payload []byte `json:"-"`
}
func NewAPIResponse ¶
func NewAPIResponse(r *http.Response) *APIResponse
func NewAPIResponseWithError ¶
func NewAPIResponseWithError(errorMessage string) *APIResponse
type AccessControlGroup ¶
type AccessControlGroup struct {
// 접근제어그룹설정번호
AccessControlGroupConfigurationNo *string `json:"accessControlGroupConfigurationNo,omitempty"`
// 접근제어그룹명
AccessControlGroupName *string `json:"accessControlGroupName,omitempty"`
// 접근제어그룹설명
AccessControlGroupDescription *string `json:"accessControlGroupDescription,omitempty"`
// 디폴트그룹여부
IsDefaultGroup *bool `json:"isDefaultGroup,omitempty"`
// 생성일자
CreateDate *string `json:"createDate,omitempty"`
}
type ActivityLog ¶
type ActivityLog struct {
// 액티비티번호
ActivityNo *string `json:"activityNo,omitempty"`
// 오토스케일링그룹명
AutoScalingGroupName *string `json:"autoScalingGroupName,omitempty"`
// 상태
Status *CommonCode `json:"status,omitempty"`
// 상태메세지
StatusMessage *string `json:"statusMessage,omitempty"`
// 액션원인
ActionCause *string `json:"actionCause,omitempty"`
// 설명
Description *string `json:"description,omitempty"`
// 상세설명
Details *string `json:"details,omitempty"`
// 시작일시
StartTime *string `json:"startTime,omitempty"`
// 종료일시
EndTime *string `json:"endTime,omitempty"`
}
type AdjustmentType ¶
type AdjustmentType struct {
AdjustmentType *CommonCode `json:"adjustmentType,omitempty"`
}
type AutoScalingGroup ¶
type AutoScalingGroup struct {
// 오토스케일링그룹명
AutoScalingGroupName *string `json:"autoScalingGroupName,omitempty"`
// 오토스케일링그룹번호
AutoScalingGroupNo *string `json:"autoScalingGroupNo,omitempty"`
// 론치설정명
LaunchConfigurationName *string `json:"launchConfigurationName,omitempty"`
// 론치설정번호
LaunchConfigurationNo *string `json:"launchConfigurationNo,omitempty"`
// 기대능력치
DesiredCapacity *int32 `json:"desiredCapacity,omitempty"`
// 최소사이즈
MinSize *int32 `json:"minSize,omitempty"`
// 최대사이즈
MaxSize *int32 `json:"maxSize,omitempty"`
DefaultCooldown *int32 `json:"defaultCooldown,omitempty"`
// 로드밸런서인스턴스Summary리스트
LoadBalancerInstanceSummaryList []*LoadBalancerInstanceSummary `json:"loadBalancerInstanceSummaryList,omitempty"`
// 헬스체크보류기간
HealthCheckGracePeriod *int32 `json:"healthCheckGracePeriod,omitempty"`
// 헬스체크유형
HealthCheckType *CommonCode `json:"healthCheckType,omitempty"`
// 생성일시
CreateDate *string `json:"createDate,omitempty"`
// 오토스케일링그룹에속한서버인스턴스리스트
InAutoScalingGroupServerInstanceList []*InAutoScalingGroupServerInstance `json:"inAutoScalingGroupServerInstanceList,omitempty"`
// 보류된프로세스리스트
SuspendedProcessList []*SuspendedProcess `json:"suspendedProcessList,omitempty"`
// ZONE리스트
ZoneList []*Zone `json:"zoneList,omitempty"`
}
type CommonCode ¶
type ConfigurationLog ¶
type ConfigurationLog struct {
// 설정번호
ConfigurationNo *string `json:"configurationNo,omitempty"`
// 설정액션명
ConfigurationActionName *string `json:"configurationActionName,omitempty"`
// 파라미터
Parameters *string `json:"parameters,omitempty"`
// 론치설절명
LaunchConfigurationName *string `json:"launchConfigurationName,omitempty"`
// 오토스케일링그룹명
AutoScalingGroupName *string `json:"autoScalingGroupName,omitempty"`
// 스케쥴액션명
ScheduledActionName *string `json:"scheduledActionName,omitempty"`
// 설정일시
SettingTime *string `json:"settingTime,omitempty"`
}
type CreateAutoScalingGroupRequest ¶
type CreateAutoScalingGroupRequest struct {
// 오토스케일링그룹명
AutoScalingGroupName *string `json:"autoScalingGroupName,omitempty"`
// 론치설정명
LaunchConfigurationName *string `json:"launchConfigurationName"`
// 기대용량치
DesiredCapacity *int32 `json:"desiredCapacity,omitempty"`
// 최소사이즈
MinSize *int32 `json:"minSize"`
// 최대사이즈
MaxSize *int32 `json:"maxSize"`
// 디폴트쿨다운타임
DefaultCooldown *int32 `json:"defaultCooldown,omitempty"`
// 로드밸런서명리스트
LoadBalancerNameList []*string `json:"loadBalancerNameList,omitempty"`
// 헬스체크보류기간
HealthCheckGracePeriod *int32 `json:"healthCheckGracePeriod,omitempty"`
// 헬스체크유형코드
HealthCheckTypeCode *string `json:"healthCheckTypeCode,omitempty"`
// ZONE번호리스트
ZoneNoList []*string `json:"zoneNoList"`
}
type CreateAutoScalingGroupResponse ¶
type CreateAutoScalingGroupResponse struct {
RequestId *string `json:"requestId,omitempty"`
ReturnCode *string `json:"returnCode,omitempty"`
ReturnMessage *string `json:"returnMessage,omitempty"`
TotalRows *int32 `json:"totalRows,omitempty"`
AutoScalingGroupList []*AutoScalingGroup `json:"autoScalingGroupList,omitempty"`
}
type CreateLaunchConfigurationRequest ¶
type CreateLaunchConfigurationRequest struct {
// 론치설정명
LaunchConfigurationName *string `json:"launchConfigurationName,omitempty"`
// 소프트웨어상품코드
ServerImageProductCode *string `json:"serverImageProductCode,omitempty"`
// 서버상품코드
ServerProductCode *string `json:"serverProductCode,omitempty"`
// 회원서버이미지번호
MemberServerImageNo *string `json:"memberServerImageNo,omitempty"`
// ACG설정번호리스트
AccessControlGroupConfigurationNoList []*string `json:"accessControlGroupConfigurationNoList,omitempty"`
// 로그인키명
LoginKeyName *string `json:"loginKeyName,omitempty"`
// 사용자데이터
UserData *string `json:"userData,omitempty"`
// 리전번호
RegionNo *string `json:"regionNo,omitempty"`
}
type CreateLaunchConfigurationResponse ¶
type CreateLaunchConfigurationResponse struct {
RequestId *string `json:"requestId,omitempty"`
ReturnCode *string `json:"returnCode,omitempty"`
ReturnMessage *string `json:"returnMessage,omitempty"`
TotalRows *int32 `json:"totalRows,omitempty"`
LaunchConfigurationList []*LaunchConfiguration `json:"launchConfigurationList,omitempty"`
}
type DeleteAutoScalingGroupRequest ¶
type DeleteAutoScalingGroupRequest struct {
// 오토스케일링그룹명
AutoScalingGroupName *string `json:"autoScalingGroupName"`
}
type DeleteAutoScalingLaunchConfigurationRequest ¶
type DeleteAutoScalingLaunchConfigurationRequest struct {
// 론치설정명
LaunchConfigurationName *string `json:"launchConfigurationName"`
}
type DeletePolicyRequest ¶
type DeletePolicyResponse ¶
type ExecutePolicyRequest ¶
type ExecutePolicyResponse ¶
type GetAdjustmentTypeListRequest ¶
type GetAdjustmentTypeListRequest struct {
}
type GetAdjustmentTypeListResponse ¶
type GetAdjustmentTypeListResponse struct {
RequestId *string `json:"requestId,omitempty"`
ReturnCode *string `json:"returnCode,omitempty"`
ReturnMessage *string `json:"returnMessage,omitempty"`
TotalRows *int32 `json:"totalRows,omitempty"`
AdjustmentTypeList []*AdjustmentType `json:"adjustmentTypeList,omitempty"`
}
type GetAutoScalingActivityLogListRequest ¶
type GetAutoScalingActivityLogListRequest struct {
// 액티비티번호리스트
ActivityNoList []*string `json:"activityNoList,omitempty"`
// 오토스케일링그룹명
AutoScalingGroupName *string `json:"autoScalingGroupName,omitempty"`
// 페이지번호
PageNo *int32 `json:"pageNo,omitempty"`
// 페이지사이즈
PageSize *int32 `json:"pageSize,omitempty"`
}
type GetAutoScalingActivityLogListResponse ¶
type GetAutoScalingActivityLogListResponse struct {
RequestId *string `json:"requestId,omitempty"`
ReturnCode *string `json:"returnCode,omitempty"`
ReturnMessage *string `json:"returnMessage,omitempty"`
TotalRows *int32 `json:"totalRows,omitempty"`
ActivityLogList []*ActivityLog `json:"activityLogList,omitempty"`
}
type GetAutoScalingConfigurationLogListRequest ¶
type GetAutoScalingConfigurationLogListRequest struct {
// 설정번호리스트
ConfigurationNoList []*string `json:"configurationNoList,omitempty"`
// 오토스케일링그룹명
AutoScalingGroupName *string `json:"autoScalingGroupName,omitempty"`
// 페이지번호
PageNo *int32 `json:"pageNo,omitempty"`
// 페이지사이즈
PageSize *int32 `json:"pageSize,omitempty"`
}
type GetAutoScalingConfigurationLogListResponse ¶
type GetAutoScalingConfigurationLogListResponse struct {
RequestId *string `json:"requestId,omitempty"`
ReturnCode *string `json:"returnCode,omitempty"`
ReturnMessage *string `json:"returnMessage,omitempty"`
TotalRows *int32 `json:"totalRows,omitempty"`
ConfigurationLogList []*ConfigurationLog `json:"configurationLogList,omitempty"`
}
type GetAutoScalingGroupListRequest ¶
type GetAutoScalingGroupListRequest struct {
// 오토스케일링그룹명리스트
AutoScalingGroupNameList []*string `json:"autoScalingGroupNameList,omitempty"`
// 페이지번호
PageNo *int32 `json:"pageNo,omitempty"`
// 페이지사이즈
PageSize *int32 `json:"pageSize,omitempty"`
// 소팅대상
SortedBy *string `json:"sortedBy,omitempty"`
// 소팅순서
SortingOrder *string `json:"sortingOrder,omitempty"`
// 리전번호
RegionNo *string `json:"regionNo,omitempty"`
}
type GetAutoScalingGroupListResponse ¶
type GetAutoScalingGroupListResponse struct {
RequestId *string `json:"requestId,omitempty"`
ReturnCode *string `json:"returnCode,omitempty"`
ReturnMessage *string `json:"returnMessage,omitempty"`
TotalRows *int32 `json:"totalRows,omitempty"`
AutoScalingGroupList []*AutoScalingGroup `json:"autoScalingGroupList,omitempty"`
}
type GetAutoScalingPolicyListRequest ¶
type GetAutoScalingPolicyListRequest struct {
// 정책명리스트
PolicyNameList []*string `json:"policyNameList,omitempty"`
// 오토스케일링그룹명
AutoScalingGroupName *string `json:"autoScalingGroupName,omitempty"`
// 페이지번호
PageNo *int32 `json:"pageNo,omitempty"`
// 페이지사이즈
PageSize *int32 `json:"pageSize,omitempty"`
}
type GetAutoScalingPolicyListResponse ¶
type GetAutoScalingPolicyListResponse struct {
RequestId *string `json:"requestId,omitempty"`
ReturnCode *string `json:"returnCode,omitempty"`
ReturnMessage *string `json:"returnMessage,omitempty"`
TotalRows *int32 `json:"totalRows,omitempty"`
ScalingPolicyList []*ScalingPolicy `json:"scalingPolicyList,omitempty"`
}
type GetLaunchConfigurationListRequest ¶
type GetLaunchConfigurationListRequest struct {
// 론치설정명리스트
LaunchConfigurationNameList []*string `json:"launchConfigurationNameList,omitempty"`
// 페이지번호
PageNo *int32 `json:"pageNo,omitempty"`
// 페이지사이즈
PageSize *int32 `json:"pageSize,omitempty"`
// 소팅대상
SortedBy *string `json:"sortedBy,omitempty"`
// 소팅순서
SortingOrder *string `json:"sortingOrder,omitempty"`
// 리전번호
RegionNo *string `json:"regionNo,omitempty"`
}
type GetLaunchConfigurationListResponse ¶
type GetLaunchConfigurationListResponse struct {
RequestId *string `json:"requestId,omitempty"`
ReturnCode *string `json:"returnCode,omitempty"`
ReturnMessage *string `json:"returnMessage,omitempty"`
TotalRows *int32 `json:"totalRows,omitempty"`
LaunchConfigurationList []*LaunchConfiguration `json:"launchConfigurationList,omitempty"`
}
type GetScalingProcessTypeListRequest ¶
type GetScalingProcessTypeListRequest struct {
}
type GetScalingProcessTypeListResponse ¶
type GetScalingProcessTypeListResponse struct {
RequestId *string `json:"requestId,omitempty"`
ReturnCode *string `json:"returnCode,omitempty"`
ReturnMessage *string `json:"returnMessage,omitempty"`
TotalRows *int32 `json:"totalRows,omitempty"`
ProcessList []*Process `json:"processList,omitempty"`
}
type GetScheduledActionListRequest ¶
type GetScheduledActionListRequest struct {
// 오토스케일링그룹명
AutoScalingGroupName *string `json:"autoScalingGroupName,omitempty"`
// 스케쥴액션명리스트
ScheduledActionNameList []*string `json:"scheduledActionNameList,omitempty"`
// 스케쥴시작일시, format : yyyy-MM-dd'T'HH:mm:ssZ
StartTime *string `json:"startTime,omitempty"`
// 스케쥴종료일시, format : yyyy-MM-dd'T'HH:mm:ssZ
EndTime *string `json:"endTime,omitempty"`
// 페이지번호
PageNo *int32 `json:"pageNo,omitempty"`
// 페이지사이즈
PageSize *int32 `json:"pageSize,omitempty"`
// 소팅대상
SortedBy *string `json:"sortedBy,omitempty"`
// 소팅순서
SortingOrder *string `json:"sortingOrder,omitempty"`
}
type GetScheduledActionListResponse ¶
type GetScheduledActionListResponse struct {
RequestId *string `json:"requestId,omitempty"`
ReturnCode *string `json:"returnCode,omitempty"`
ReturnMessage *string `json:"returnMessage,omitempty"`
TotalRows *int32 `json:"totalRows,omitempty"`
ScheduledUpdateGroupActionList []*ScheduledUpdateGroupAction `json:"scheduledUpdateGroupActionList,omitempty"`
}
type InAutoScalingGroupServerInstance ¶
type InAutoScalingGroupServerInstance struct {
// 헬스상태
HealthStatus *CommonCode `json:"healthStatus,omitempty"`
// 라이프사이클상태
LifecycleState *CommonCode `json:"lifecycleState,omitempty"`
// 론치설정
LaunchConfiguration *LaunchConfiguration `json:"launchConfiguration,omitempty"`
// 서버인스턴스번호
ServerInstanceNo *string `json:"serverInstanceNo,omitempty"`
// 서버인스턴스명
ServerInstanceName *string `json:"serverInstanceName,omitempty"`
}
type LaunchConfiguration ¶
type LaunchConfiguration struct {
// 론치설정명
LaunchConfigurationName *string `json:"launchConfigurationName,omitempty"`
// 론치설정번호
LaunchConfigurationNo *string `json:"launchConfigurationNo,omitempty"`
// 서버이미지상품코드
ServerImageProductCode *string `json:"serverImageProductCode,omitempty"`
// 서버상품코드
ServerProductCode *string `json:"serverProductCode,omitempty"`
// 회원서버이미지번호
MemberServerImageNo *string `json:"memberServerImageNo,omitempty"`
// 로그인키명
LoginKeyName *string `json:"loginKeyName,omitempty"`
// 생성일시
CreateDate *string `json:"createDate,omitempty"`
// 사용자데이터
UserData *string `json:"userData,omitempty"`
// ACG리스트
AccessControlGroupList []*AccessControlGroup `json:"accessControlGroupList,omitempty"`
}
type Process ¶
type Process struct {
Process *CommonCode `json:"process,omitempty"`
}
type PutScalingPolicyRequest ¶
type PutScalingPolicyRequest struct {
// 조정유형코드
AdjustmentTypeCode *string `json:"adjustmentTypeCode"`
// 오토스케일링그룹명
AutoScalingGroupName *string `json:"autoScalingGroupName"`
// 쿨다운타임
Cooldown *int32 `json:"cooldown,omitempty"`
// 최소조정스텝
MinAdjustmentStep *int32 `json:"minAdjustmentStep,omitempty"`
// 정책명
PolicyName *string `json:"policyName"`
// 스케일링조정값
ScalingAdjustment *int32 `json:"scalingAdjustment"`
}
type PutScheduledUpdateGroupActionRequest ¶
type PutScheduledUpdateGroupActionRequest struct {
// 오토스케일링그룹명
AutoScalingGroupName *string `json:"autoScalingGroupName"`
// 기대용량치
DesiredCapacity *int32 `json:"desiredCapacity,omitempty"`
// 반복스케쥴종료시간
EndTime *string `json:"endTime,omitempty"`
// 최대사이즈
MaxSize *int32 `json:"maxSize,omitempty"`
// 최소사이즈
MinSize *int32 `json:"minSize,omitempty"`
// 반복스케줄설정
RecurrenceInKST *string `json:"recurrenceInKST,omitempty"`
// 스케쥴액션명
ScheduledActionName *string `json:"scheduledActionName"`
// 스케쥴시작시간
StartTime *string `json:"startTime,omitempty"`
}
type PutScheduledUpdateGroupActionResponse ¶
type PutScheduledUpdateGroupActionResponse struct {
RequestId *string `json:"requestId,omitempty"`
ReturnCode *string `json:"returnCode,omitempty"`
ReturnMessage *string `json:"returnMessage,omitempty"`
TotalRows *int32 `json:"totalRows,omitempty"`
ScheduledUpdateGroupActionList []*ScheduledUpdateGroupAction `json:"scheduledUpdateGroupActionList,omitempty"`
}
type ResumeProcessesRequest ¶
type ResumeProcessesResponse ¶
type ScalingPolicy ¶
type ScalingPolicy struct {
PolicyName *string `json:"policyName,omitempty"`
AutoScalingGroupName *string `json:"autoScalingGroupName,omitempty"`
AdjustmentType *CommonCode `json:"adjustmentType,omitempty"`
ScalingAdjustment *int32 `json:"scalingAdjustment,omitempty"`
Cooldown *int32 `json:"cooldown,omitempty"`
MinAdjustmentStep *int32 `json:"minAdjustmentStep,omitempty"`
}
type ScheduledUpdateGroupAction ¶
type ScheduledUpdateGroupAction struct {
// 오토스케일링그룹명
AutoScalingGroupName *string `json:"autoScalingGroupName,omitempty"`
// 스케쥴액션명
ScheduledActionName *string `json:"scheduledActionName,omitempty"`
// 기대능력치
DesiredCapacity *int32 `json:"desiredCapacity,omitempty"`
// 최소사이즈
MinSize *int32 `json:"minSize,omitempty"`
// 최대사이즈
MaxSize *int32 `json:"maxSize,omitempty"`
// 스케줄시작시간
StartTime *string `json:"startTime,omitempty"`
// 반복스케쥴종료시간
EndTime *string `json:"endTime,omitempty"`
// 반복스케쥴설정
RecurrenceInKST *string `json:"recurrenceInKST,omitempty"`
}
type SetDesiredCapacityResponse ¶
type SetDesiredCapacityResponse struct {
RequestId *string `json:"requestId,omitempty"`
ReturnCode *string `json:"returnCode,omitempty"`
ReturnMessage *string `json:"returnMessage,omitempty"`
TotalRows *int32 `json:"totalRows,omitempty"`
AutoScalingGroupList []*AutoScalingGroup `json:"autoScalingGroupList,omitempty"`
}
type SuspendProcessesRequest ¶
type SuspendedProcess ¶
type SuspendedProcess struct {
// 프로세스
Process *CommonCode `json:"process,omitempty"`
// 프로세스보류원인
SuspensionReason *string `json:"suspensionReason,omitempty"`
}
type UpdateAutoScalingGroupRequest ¶
type UpdateAutoScalingGroupRequest struct {
// 오토스케일링그룹명
AutoScalingGroupName *string `json:"autoScalingGroupName,omitempty"`
// 론치설정명
LaunchConfigurationName *string `json:"launchConfigurationName"`
// 기대용량치
DesiredCapacity *int32 `json:"desiredCapacity,omitempty"`
// 최소사이즈
MinSize *int32 `json:"minSize,omitempty"`
// 최대사이즈
MaxSize *int32 `json:"maxSize,omitempty"`
// 디폴트쿨다운타임
DefaultCooldown *int32 `json:"defaultCooldown,omitempty"`
// 헬스체크보류기간
HealthCheckGracePeriod *int32 `json:"healthCheckGracePeriod,omitempty"`
// 헬스체크유형코드
HealthCheckTypeCode *string `json:"healthCheckTypeCode,omitempty"`
// ZONE번호리스트
ZoneNoList []*string `json:"zoneNoList,omitempty"`
}
type UpdateAutoScalingGroupResponse ¶
type UpdateAutoScalingGroupResponse struct {
RequestId *string `json:"requestId,omitempty"`
ReturnCode *string `json:"returnCode,omitempty"`
ReturnMessage *string `json:"returnMessage,omitempty"`
TotalRows *int32 `json:"totalRows,omitempty"`
AutoScalingGroupList []*AutoScalingGroup `json:"autoScalingGroupList,omitempty"`
}
type V2ApiService ¶
type V2ApiService service
func (*V2ApiService) CreateAutoScalingGroup ¶
func (a *V2ApiService) CreateAutoScalingGroup(createAutoScalingGroupRequest *CreateAutoScalingGroupRequest) (*CreateAutoScalingGroupResponse, error)
V2ApiService B.오토스케일링그룹생성 @param createAutoScalingGroupRequest createAutoScalingGroupRequest @return *CreateAutoScalingGroupResponse
func (*V2ApiService) CreateLaunchConfiguration ¶
func (a *V2ApiService) CreateLaunchConfiguration(createLaunchConfigurationRequest *CreateLaunchConfigurationRequest) (*CreateLaunchConfigurationResponse, error)
V2ApiService A.론치설정생성 @param createLaunchConfigurationRequest createLaunchConfigurationRequest @return *CreateLaunchConfigurationResponse
func (*V2ApiService) DeleteAutoScalingGroup ¶
func (a *V2ApiService) DeleteAutoScalingGroup(deleteAutoScalingGroupRequest *DeleteAutoScalingGroupRequest) (*DeleteAutoScalingGroupResponse, error)
V2ApiService B.오토스케일링그룹삭제 @param deleteAutoScalingGroupRequest deleteAutoScalingGroupRequest @return *DeleteAutoScalingGroupResponse
func (*V2ApiService) DeleteAutoScalingLaunchConfiguration ¶
func (a *V2ApiService) DeleteAutoScalingLaunchConfiguration(deleteAutoScalingLaunchConfigurationRequest *DeleteAutoScalingLaunchConfigurationRequest) (*DeleteAutoScalingLaunchConfigurationRequest, error)
V2ApiService A.오토스케일링론치설정삭제 @param deleteAutoScalingLaunchConfigurationRequest deleteAutoScalingLaunchConfigurationRequest @return *DeleteAutoScalingLaunchConfigurationRequest
func (*V2ApiService) DeletePolicy ¶
func (a *V2ApiService) DeletePolicy(deletePolicyRequest *DeletePolicyRequest) (*DeletePolicyResponse, error)
V2ApiService F.스케일링정책삭제 @param deletePolicyRequest deletePolicyRequest @return *DeletePolicyResponse
func (*V2ApiService) DeleteScheduledAction ¶
func (a *V2ApiService) DeleteScheduledAction(deleteScheduledActionRequest *DeleteScheduledActionRequest) (*DeleteScheduledActionResponse, error)
V2ApiService C.스케쥴액션삭제 @param deleteScheduledActionRequest deleteScheduledActionRequest @return *DeleteScheduledActionResponse
func (*V2ApiService) ExecutePolicy ¶
func (a *V2ApiService) ExecutePolicy(executePolicyRequest *ExecutePolicyRequest) (*ExecutePolicyResponse, error)
V2ApiService F.스케일링정책수행 @param executePolicyRequest executePolicyRequest @return *ExecutePolicyResponse
func (*V2ApiService) GetAdjustmentTypeList ¶
func (a *V2ApiService) GetAdjustmentTypeList(getAdjustmentTypeListRequest *GetAdjustmentTypeListRequest) (*GetAdjustmentTypeListResponse, error)
V2ApiService F.조정유형리스트조회 @param getAdjustmentTypeListRequest getAdjustmentTypeListRequest @return *GetAdjustmentTypeListResponse
func (*V2ApiService) GetAutoScalingActivityLogList ¶
func (a *V2ApiService) GetAutoScalingActivityLogList(getAutoScalingActivityLogListRequest *GetAutoScalingActivityLogListRequest) (*GetAutoScalingActivityLogListResponse, error)
V2ApiService E.액티비티로그리스트조회 @param getAutoScalingActivityLogListRequest getAutoScalingActivityLogListRequest @return *GetAutoScalingActivityLogListResponse
func (*V2ApiService) GetAutoScalingConfigurationLogList ¶
func (a *V2ApiService) GetAutoScalingConfigurationLogList(getAutoScalingConfigurationLogListRequest *GetAutoScalingConfigurationLogListRequest) (*GetAutoScalingConfigurationLogListResponse, error)
V2ApiService E.오토스케일링설정로그리스트조회 @param getAutoScalingConfigurationLogListRequest getAutoScalingConfigurationLogListRequest @return *GetAutoScalingConfigurationLogListResponse
func (*V2ApiService) GetAutoScalingGroupList ¶
func (a *V2ApiService) GetAutoScalingGroupList(getAutoScalingGroupListRequest *GetAutoScalingGroupListRequest) (*GetAutoScalingGroupListResponse, error)
V2ApiService B.오토스케일링그룹리스트조회 @param getAutoScalingGroupListRequest getAutoScalingGroupListRequest @return *GetAutoScalingGroupListResponse
func (*V2ApiService) GetAutoScalingPolicyList ¶
func (a *V2ApiService) GetAutoScalingPolicyList(getAutoScalingPolicyListRequest *GetAutoScalingPolicyListRequest) (*GetAutoScalingPolicyListResponse, error)
V2ApiService F.오토스케일링정책리스트조회 @param getAutoScalingPolicyListRequest getAutoScalingPolicyListRequest @return *GetAutoScalingPolicyListResponse
func (*V2ApiService) GetLaunchConfigurationList ¶
func (a *V2ApiService) GetLaunchConfigurationList(getLaunchConfigurationListRequest *GetLaunchConfigurationListRequest) (*GetLaunchConfigurationListResponse, error)
V2ApiService A.론치설정리스트조회 @param getLaunchConfigurationListRequest getLaunchConfigurationListRequest @return *GetLaunchConfigurationListResponse
func (*V2ApiService) GetScalingProcessTypeList ¶
func (a *V2ApiService) GetScalingProcessTypeList(getScalingProcessTypeListRequest *GetScalingProcessTypeListRequest) (*GetScalingProcessTypeListResponse, error)
V2ApiService D.프로세스구분리스트조회 @param getScalingProcessTypeListRequest getScalingProcessTypeListRequest @return *GetScalingProcessTypeListResponse
func (*V2ApiService) GetScheduledActionList ¶
func (a *V2ApiService) GetScheduledActionList(getScheduledActionListRequest *GetScheduledActionListRequest) (*GetScheduledActionListResponse, error)
V2ApiService C.스케쥴액션리스트조회 @param getScheduledActionListRequest getScheduledActionListRequest @return *GetScheduledActionListResponse
func (*V2ApiService) PutScalingPolicy ¶
func (a *V2ApiService) PutScalingPolicy(putScalingPolicyRequest *PutScalingPolicyRequest) (*PutScalingPolicyResponse, error)
V2ApiService F.스케일링정책생성/변경 @param putScalingPolicyRequest putScalingPolicyRequest @return *PutScalingPolicyResponse
func (*V2ApiService) PutScheduledUpdateGroupAction ¶
func (a *V2ApiService) PutScheduledUpdateGroupAction(putScheduledUpdateGroupActionRequest *PutScheduledUpdateGroupActionRequest) (*PutScheduledUpdateGroupActionResponse, error)
V2ApiService C.스케쥴액션생성|수정 @param putScheduledUpdateGroupActionRequest putScheduledUpdateGroupActionRequest @return *PutScheduledUpdateGroupActionResponse
func (*V2ApiService) ResumeProcesses ¶
func (a *V2ApiService) ResumeProcesses(resumeProcessesRequest *ResumeProcessesRequest) (*ResumeProcessesResponse, error)
V2ApiService D.프로세스재개 @param resumeProcessesRequest resumeProcessesRequest @return *ResumeProcessesResponse
func (*V2ApiService) SetDesiredCapacity ¶
func (a *V2ApiService) SetDesiredCapacity(setDesiredCapacityRequest *SetDesiredCapacityRequest) (*SetDesiredCapacityResponse, error)
V2ApiService B.기대용량치갱신 @param setDesiredCapacityRequest setDesiredCapacityRequest @return *SetDesiredCapacityResponse
func (*V2ApiService) SetServerInstanceHealth ¶
func (a *V2ApiService) SetServerInstanceHealth(setServerInstanceHealthRequest *SetServerInstanceHealthRequest) (*SetServerInstanceHealthResponse, error)
V2ApiService B.서버인스턴스헬스상태갱신 @param setServerInstanceHealthRequest setServerInstanceHealthRequest @return *SetServerInstanceHealthResponse
func (*V2ApiService) SuspendProcesses ¶
func (a *V2ApiService) SuspendProcesses(suspendProcessesRequest *SuspendProcessesRequest) (*SuspendProcessesResponse, error)
V2ApiService D.프로세스보류 @param suspendProcessesRequest suspendProcessesRequest @return *SuspendProcessesResponse
func (*V2ApiService) TerminateServerInstanceInAutoScalingGroup ¶
func (a *V2ApiService) TerminateServerInstanceInAutoScalingGroup(terminateServerInstanceInAutoScalingGroupRequest *TerminateServerInstanceInAutoScalingGroupRequest) (*TerminateServerInstanceInAutoScalingGroupResponse, error)
V2ApiService B.오토스케일링그룹에속한서버인스턴스삭제 @param terminateServerInstanceInAutoScalingGroupRequest terminateServerInstanceInAutoScalingGroupRequest @return *TerminateServerInstanceInAutoScalingGroupResponse
func (*V2ApiService) UpdateAutoScalingGroup ¶
func (a *V2ApiService) UpdateAutoScalingGroup(updateAutoScalingGroupRequest *UpdateAutoScalingGroupRequest) (*UpdateAutoScalingGroupResponse, error)
V2ApiService B.오토스케일링그룹수정 @param updateAutoScalingGroupRequest updateAutoScalingGroupRequest @return *UpdateAutoScalingGroupResponse
Source Files
¶
- access_control_group.go
- activity_log.go
- adjustment_type.go
- api_client.go
- api_response.go
- auto_scaling_group.go
- common_code.go
- configuration.go
- configuration_log.go
- create_auto_scaling_group_request.go
- create_auto_scaling_group_response.go
- create_launch_configuration_request.go
- create_launch_configuration_response.go
- delete_auto_scaling_group_request.go
- delete_auto_scaling_group_response.go
- delete_auto_scaling_launch_configuration_request.go
- delete_auto_scaling_launch_configuration_response.go
- delete_policy_request.go
- delete_policy_response.go
- delete_scheduled_action_request.go
- delete_scheduled_action_response.go
- execute_policy_request.go
- execute_policy_response.go
- get_adjustment_type_list_request.go
- get_adjustment_type_list_response.go
- get_auto_scaling_activity_log_list_request.go
- get_auto_scaling_activity_log_list_response.go
- get_auto_scaling_configuration_log_list_request.go
- get_auto_scaling_configuration_log_list_response.go
- get_auto_scaling_group_list_request.go
- get_auto_scaling_group_list_response.go
- get_auto_scaling_policy_list_request.go
- get_auto_scaling_policy_list_response.go
- get_launch_configuration_list_request.go
- get_launch_configuration_list_response.go
- get_scaling_process_type_list_request.go
- get_scaling_process_type_list_response.go
- get_scheduled_action_list_request.go
- get_scheduled_action_list_response.go
- in_auto_scaling_group_server_instance.go
- launch_configuration.go
- load_balancer_instance_summary.go
- process.go
- put_scaling_policy_request.go
- put_scaling_policy_response.go
- put_scheduled_update_group_action_request.go
- put_scheduled_update_group_action_response.go
- resume_processes_request.go
- resume_processes_response.go
- scaling_policy.go
- scheduled_update_group_action.go
- set_desired_capacity_request.go
- set_desired_capacity_response.go
- set_server_instance_health_request.go
- set_server_instance_health_response.go
- suspend_processes_request.go
- suspend_processes_response.go
- suspended_process.go
- terminate_server_instance_in_auto_scaling_group_request.go
- terminate_server_instance_in_auto_scaling_group_response.go
- update_auto_scaling_group_request.go
- update_auto_scaling_group_response.go
- v2_api.go
- zone.go