Documentation
¶
Index ¶
- func CacheExpires(r *http.Response) time.Time
- func NewConfiguration(region string, apiKeys ...*ncloud.APIKey) *ncloud.Configuration
- type APIClient
- type APIResponse
- type AcgRuleResponseDetailVo
- type AddNodesInCluster
- type AllowedClusterInfo
- type BucketInfo
- type CatIndice
- type CreateCluster
- type CreateClusterResponseVo
- type CreateImportJob
- type CreateSnapshot
- type DateTimeVo
- type DimensionsVo
- type DisallowedClusterInfo
- type ElasticSearchVersion
- type GenericSwaggerError
- type GetClusterIndicesStatusResponseVo
- type GetClusterRequest
- type GetClusterStatusResponseVo
- type GetElasticSearchVersionListResponseVo
- type GetElasticsearchMonitoringData
- type GetImportHistoryListResponseVo
- type GetObjectStorageBucketListResponseVo
- type GetOpenApiAccessControlGroupRuleListResponseVo
- type GetOpenApiAcgInfoList
- type GetOpenApiDashboardInformationResponseVo
- type GetOpenApiHwProductListResponseVo
- type GetOpenApiLoginKeyListResponseVo
- type GetOpenApiOsProductListResponseVo
- type GetOpenApiServiceGroupResponseVo
- type GetOsMonitoringData
- type GetSnapshotSchedulingHistory
- type GetSnapshotSchedulingHistoryResponseVo
- type GetSubnetList
- type GetVpcConfigListResponseDetailVo
- type GetVpcConfigListResponseVo
- type GetVpcSubnetListResponseVo
- type ImportHistoryVo
- type MetricInfoResponseVo
- type NodeProduct
- type OpenApiGetClusterInfoListResponseVo
- type OpenApiGetClusterInfoResponseVo
- type OpenApiGetComputeInstanceListResponseDetailVo
- type OpenApiHwProductVo
- type OpenApiLoginKeyVo
- type OpenApiOsProductVo
- type QueryMultipleDataResponseVo
- type ResetKibanaPassword
- type ResponseVoBoolean
- type ResponseVoCreateClusterResponseVo
- type ResponseVoGetElasticSearchVersionListResponseVo
- type ResponseVoGetImportHistoryListResponseVo
- type ResponseVoGetObjectStorageBucketListResponseVo
- type ResponseVoGetOpenApiAcgInfoList
- type ResponseVoGetOpenApiDashboardInformationResponseVo
- type ResponseVoGetOpenApiHwProductListResponseVo
- type ResponseVoGetOpenApiLoginKeyListResponseVo
- type ResponseVoGetOpenApiOsProductListResponseVo
- type ResponseVoGetOpenApiServiceGroupResponseVo
- type ResponseVoGetSnapshotSchedulingHistoryResponseVo
- type ResponseVoGetVpcConfigListResponseVo
- type ResponseVoGetVpcSubnetListResponseVo
- type ResponseVoOpenApiGetClusterInfoListResponseVo
- type ResponseVoOpenApiGetClusterInfoResponseVo
- type ResponseVoQueryMultipleDataResponseVo
- type ResponseVoSnapshotHistoryListResponseVo
- type SetSnapshotScheduling
- type SnapshotHistoryListResponseVo
- type SnapshotHistoryResponseVo
- type SnapshotSchedulingHistoryResponseVo
- type UpdateApiAuthenticationKey
- type V1ApiDashboardGetDashboardInformationServiceGroupInstanceNoGetOpts
- type V1ApiImportGetDataImportHistoryServiceGroupInstanceNoGetOpts
- type V1ApiService
- func (a *V1ApiService) ClusterChangeCountOfDataNodeServiceGroupInstanceNoPost(ctx context.Context, changeCountOfDataNode AddNodesInCluster, ...) (ResponseVoBoolean, *http.Response, error)
- func (a *V1ApiService) ClusterCreateElasticsearchClusterPost(ctx context.Context, createCluster *CreateCluster) (ResponseVoCreateClusterResponseVo, *http.Response, error)
- func (a *V1ApiService) ClusterDeleteElasticsearchClusterServiceGroupInstanceNoDelete(ctx context.Context, serviceGroupInstanceNo *string) (ResponseVoBoolean, *http.Response, error)
- func (a *V1ApiService) ClusterGetAcgInfoListServiceGroupInstanceNoGet(ctx context.Context, serviceGroupInstanceNo string) (ResponseVoGetOpenApiAcgInfoList, *http.Response, error)
- func (a *V1ApiService) ClusterGetClusterDataNodeListServiceGroupInstanceNoGet(ctx context.Context, serviceGroupInstanceNo string) (ResponseVoGetOpenApiServiceGroupResponseVo, *http.Response, error)
- func (a *V1ApiService) ClusterGetClusterInfoGet(ctx context.Context, serviceGroupInstanceNo *string) (ResponseVoOpenApiGetClusterInfoResponseVo, *http.Response, error)
- func (a *V1ApiService) ClusterGetClusterInfoListPost(ctx context.Context, clusterInfoRequest *GetClusterRequest) (ResponseVoOpenApiGetClusterInfoListResponseVo, *http.Response, error)
- func (a *V1ApiService) ClusterGetElasticsearchVersionListGet(ctx context.Context) (ResponseVoGetElasticSearchVersionListResponseVo, *http.Response, error)
- func (a *V1ApiService) ClusterGetLoginKeyListGet(ctx context.Context) (ResponseVoGetOpenApiLoginKeyListResponseVo, *http.Response, error)
- func (a *V1ApiService) ClusterGetNodeProductListPost(ctx context.Context, getNodeProductList NodeProduct) (ResponseVoGetOpenApiHwProductListResponseVo, *http.Response, error)
- func (a *V1ApiService) ClusterGetOsProductListGet(ctx context.Context) (ResponseVoGetOpenApiOsProductListResponseVo, *http.Response, error)
- func (a *V1ApiService) ClusterGetSubnetListPost(ctx context.Context, getSubnetList GetSubnetList) (ResponseVoGetVpcSubnetListResponseVo, *http.Response, error)
- func (a *V1ApiService) ClusterGetVpcListGet(ctx context.Context) (ResponseVoGetVpcConfigListResponseVo, *http.Response, error)
- func (a *V1ApiService) ClusterResetKibanaPasswordServiceGroupInstanceNoPost(ctx context.Context, kibanaPassword ResetKibanaPassword, ...) (ResponseVoBoolean, *http.Response, error)
- func (a *V1ApiService) ClusterRestartElasticsearchClusterServiceGroupInstanceNoGet(ctx context.Context, serviceGroupInstanceNo string) (ResponseVoBoolean, *http.Response, error)
- func (a *V1ApiService) DashboardGetDashboardInformationServiceGroupInstanceNoGet(ctx context.Context, serviceGroupInstanceNo string, ...) (ResponseVoGetOpenApiDashboardInformationResponseVo, *http.Response, error)
- func (a *V1ApiService) ImportCreateDataImportJobServiceGroupInstanceNoPost(ctx context.Context, createImportJob CreateImportJob, ...) (ResponseVoBoolean, *http.Response, error)
- func (a *V1ApiService) ImportGetBucketListServiceGroupInstanceNoGet(ctx context.Context, serviceGroupInstanceNo string) (ResponseVoBoolean, *http.Response, error)
- func (a *V1ApiService) ImportGetDataImportHistoryServiceGroupInstanceNoGet(ctx context.Context, serviceGroupInstanceNo string, ...) (ResponseVoGetImportHistoryListResponseVo, *http.Response, error)
- func (a *V1ApiService) ImportStopDataImportJobServiceGroupInstanceNoGet(ctx context.Context, serviceGroupInstanceNo string) (ResponseVoBoolean, *http.Response, error)
- func (a *V1ApiService) MonitoringGetElasticsearchMonitoringDataServiceGroupInstanceNoPost(ctx context.Context, ...) (ResponseVoQueryMultipleDataResponseVo, *http.Response, error)
- func (a *V1ApiService) MonitoringGetOsMonitoringDataServiceGroupInstanceNoPost(ctx context.Context, getOsMonitoringData GetOsMonitoringData, ...) (ResponseVoQueryMultipleDataResponseVo, *http.Response, error)
- func (a *V1ApiService) SnapshotCreateSnapshotServiceGroupInstanceNoPost(ctx context.Context, createSnapshot CreateSnapshot, ...) (ResponseVoBoolean, *http.Response, error)
- func (a *V1ApiService) SnapshotGetBucketListServiceGroupInstanceNoGet(ctx context.Context, serviceGroupInstanceNo string) (ResponseVoGetObjectStorageBucketListResponseVo, *http.Response, error)
- func (a *V1ApiService) SnapshotGetSnapshotHistoryServiceGroupInstanceNoGet(ctx context.Context, serviceGroupInstanceNo string, ...) (ResponseVoSnapshotHistoryListResponseVo, *http.Response, error)
- func (a *V1ApiService) SnapshotGetSnapshotSchedulingHistoryServiceGroupInstanceNoPost(ctx context.Context, getSnapshotSchedulingHistory GetSnapshotSchedulingHistory, ...) (ResponseVoGetSnapshotSchedulingHistoryResponseVo, *http.Response, error)
- func (a *V1ApiService) SnapshotReleaseSnapshotSchedulingServiceGroupInstanceNoGet(ctx context.Context, serviceGroupInstanceNo string) (ResponseVoBoolean, *http.Response, error)
- func (a *V1ApiService) SnapshotSetSnapshotSchedulingServiceGroupInstanceNoPost(ctx context.Context, setSnapshotScheduling SetSnapshotScheduling, ...) (ResponseVoBoolean, *http.Response, error)
- func (a *V1ApiService) SnapshotUpdateAPIAuthenticationKeyServiceGroupInstanceNoPost(ctx context.Context, updateAPIAuthenticationKey UpdateApiAuthenticationKey, ...) (ResponseVoBoolean, *http.Response, error)
- type V1ApiSnapshotGetSnapshotHistoryServiceGroupInstanceNoGetOpts
- type VpcSubnetListResponseDetailVo
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CacheExpires ¶
CacheExpires helper function to determine remaining time before repeating a request.
func NewConfiguration ¶
func NewConfiguration(region string, apiKeys ...*ncloud.APIKey) *ncloud.Configuration
Types ¶
type APIClient ¶
type APIClient struct {
V1Api *V1ApiService
// contains filtered or unexported fields
}
APIClient manages communication with the api API v2021-12-21T11:54:01Z In most cases there should be only one, shared, APIClient.
func NewAPIClient ¶
func NewAPIClient(cfg *ncloud.Configuration) *APIClient
NewAPIClient creates a new API client. Requires a userAgent string describing your application. optionally a custom http.Client to allow for advanced features such as caching.
func (*APIClient) ChangeBasePath ¶
Change base path to allow switching to mocks
type APIResponse ¶
type APIResponse struct {
*http.Response `json:"-"`
Message string `json:"message,omitempty"`
// Operation is the name of the swagger operation.
Operation string `json:"operation,omitempty"`
// RequestURL is the request URL. This value is always available, even if the
// embedded *http.Response is nil.
RequestURL string `json:"url,omitempty"`
// Method is the HTTP method used for the request. This value is always
// available, even if the embedded *http.Response is nil.
Method string `json:"method,omitempty"`
// Payload holds the contents of the response body (which may be nil or empty).
// This is provided here as the raw response.Body() reader will have already
// been drained.
Payload []byte `json:"-"`
}
func NewAPIResponse ¶
func NewAPIResponse(r *http.Response) *APIResponse
func NewAPIResponseWithError ¶
func NewAPIResponseWithError(errorMessage string) *APIResponse
type AcgRuleResponseDetailVo ¶
type AcgRuleResponseDetailVo struct {
AccessControlGroupName string `json:"accessControlGroupName,omitempty"`
AccessControlGroupNo int32 `json:"accessControlGroupNo,omitempty"`
AccessControlGroupRuleNo int32 `json:"accessControlGroupRuleNo,omitempty"`
AccessControlGroupSequence int32 `json:"accessControlGroupSequence,omitempty"`
CreatedYmdt *DateTimeVo `json:"createdYmdt,omitempty"`
Description string `json:"description,omitempty"`
IpBlock string `json:"ipBlock,omitempty"`
IsInboundRule bool `json:"isInboundRule,omitempty"`
PortRange string `json:"portRange,omitempty"`
ProtocolTypeCode string `json:"protocolTypeCode,omitempty"`
StatusCode string `json:"statusCode,omitempty"`
}
type AddNodesInCluster ¶
type AddNodesInCluster struct {
NewDataNodeCount int32 `json:"newDataNodeCount"`
}
type AllowedClusterInfo ¶
type AllowedClusterInfo struct {
AccessKeyId string `json:"accessKeyId,omitempty"`
ClusterName string `json:"clusterName,omitempty"`
// clusterStatus (creating[blue], changing[yelllow], running[green], error[red], deleting[gray], return[gray])
ClusterStatus string `json:"clusterStatus"`
CreateDate string `json:"createDate,omitempty"`
DataNodeAccessControlGroupName string `json:"dataNodeAccessControlGroupName,omitempty"`
DataNodeAccessControlGroupSequence int32 `json:"dataNodeAccessControlGroupSequence,omitempty"`
DataNodeCount int32 `json:"dataNodeCount,omitempty"`
DataNodeProductName string `json:"dataNodeProductName,omitempty"`
DataNodeSubnetName string `json:"dataNodeSubnetName,omitempty"`
DataNodeSubnetNo int32 `json:"dataNodeSubnetNo,omitempty"`
DataNodeType string `json:"dataNodeType,omitempty"`
DataStorageVolumeSize int64 `json:"dataStorageVolumeSize,omitempty"`
ElasticSearchHttpPort string `json:"elasticSearchHttpPort,omitempty"`
// elasticSearchStatus (green, yellow, orange, red, gray)
ElasticSearchStatus string `json:"elasticSearchStatus"`
ElasticSearchVersion string `json:"elasticSearchVersion,omitempty"`
IsDualManager bool `json:"isDualManager,omitempty"`
IsMasterOnlyNodeActivated bool `json:"isMasterOnlyNodeActivated,omitempty"`
IsPluginInstalled bool `json:"isPluginInstalled,omitempty"`
KibanaHttpPort string `json:"kibanaHttpPort,omitempty"`
KibanaUserName string `json:"kibanaUserName,omitempty"`
LoginKeyName string `json:"loginKeyName,omitempty"`
ManagerNodeAccessControlGroupName string `json:"managerNodeAccessControlGroupName,omitempty"`
ManagerNodeAccessControlGroupSequence int32 `json:"managerNodeAccessControlGroupSequence,omitempty"`
ManagerNodeCount int32 `json:"managerNodeCount,omitempty"`
ManagerNodeSubnetName string `json:"managerNodeSubnetName,omitempty"`
ManagerNodeSubnetNo int32 `json:"managerNodeSubnetNo,omitempty"`
ManagerNodeType string `json:"managerNodeType,omitempty"`
MasterNodeAccessControlGroupName string `json:"masterNodeAccessControlGroupName,omitempty"`
MasterNodeAccessControlGroupSequence int32 `json:"masterNodeAccessControlGroupSequence,omitempty"`
MasterNodeCount int32 `json:"masterNodeCount,omitempty"`
MasterNodeProductName string `json:"masterNodeProductName,omitempty"`
MasterNodeSubnetName string `json:"masterNodeSubnetName,omitempty"`
MasterNodeSubnetNo int32 `json:"masterNodeSubnetNo,omitempty"`
MasterNodeType string `json:"masterNodeType,omitempty"`
MemberNo string `json:"memberNo,omitempty"`
ServiceGroupInstanceNo *string `json:"serviceGroupInstanceNo,omitempty"`
SoftwareProductName string `json:"softwareProductName,omitempty"`
VpcName string `json:"vpcName,omitempty"`
VpcNo int32 `json:"vpcNo,omitempty"`
}
type BucketInfo ¶
type BucketInfo struct {
ActionName string `json:"actionName,omitempty"`
BucketProtectionState string `json:"bucketProtectionState,omitempty"`
BytesUsed int64 `json:"bytesUsed,omitempty"`
CreationTime int64 `json:"creationTime,omitempty"`
Disabled bool `json:"disabled,omitempty"`
Enable bool `json:"enable,omitempty"`
Name string `json:"name,omitempty"`
ObjectCount int64 `json:"objectCount,omitempty"`
Permission string `json:"permission,omitempty"`
SseKmsEnabled bool `json:"sseKmsEnabled,omitempty"`
}
type CatIndice ¶
type CatIndice struct {
DocsCount string `json:"docsCount,omitempty"`
DocsDeleted string `json:"docsDeleted,omitempty"`
Health string `json:"health,omitempty"`
IndexName string `json:"indexName,omitempty"`
PrimaryCount string `json:"primaryCount,omitempty"`
ReplicaCount string `json:"replicaCount,omitempty"`
Status string `json:"status,omitempty"`
StoreSize string `json:"storeSize,omitempty"`
Uuid string `json:"uuid,omitempty"`
}
type CreateCluster ¶
type CreateCluster struct {
ClusterName *string `json:"clusterName"`
ElasticSearchVersionCode *string `json:"elasticSearchVersionCode"`
KibanaHttpPort *string `json:"kibanaHttpPort"`
KibanaUserName *string `json:"kibanaUserName"`
KibanaUserPassword *string `json:"kibanaUserPassword"`
SoftwareProductCode *string `json:"softwareProductCode"`
VpcNo *int32 `json:"vpcNo"`
ManagerNodeProductCode *string `json:"managerNodeProductCode"`
ManagerNodeSubnetNo *int32 `json:"managerNodeSubnetNo"`
DataNodeProductCode *string `json:"dataNodeProductCode"`
DataNodeCount *int32 `json:"dataNodeCount"`
DataNodeSubnetNo *int32 `json:"dataNodeSubnetNo"`
DataNodeStorageSize *int32 `json:"dataNodeStorageSize"`
LoginKeyName *string `json:"loginKeyName"`
IsDualManager *bool `json:"isDualManager"`
IsMasterOnlyNodeActivated *bool `json:"isMasterOnlyNodeActivated"`
MasterNodeSubnetNo *int32 `json:"masterNodeSubnetNo,omitempty"`
MasterNodeProductCode *string `json:"masterNodeProductCode,omitempty"`
MasterNodeCount *int32 `json:"masterNodeCount,omitempty"`
}
type CreateClusterResponseVo ¶
type CreateClusterResponseVo struct {
// 서비스 그룹 인스턴스 번호
ServiceGroupInstanceNo *int32 `json:"serviceGroupInstanceNo"`
}
type CreateImportJob ¶
type CreateSnapshot ¶
type DateTimeVo ¶
type DimensionsVo ¶
type DisallowedClusterInfo ¶
type DisallowedClusterInfo struct {
ClusterName string `json:"clusterName,omitempty"`
// clusterStatus (creating[blue], changing[yelllow], running[green], error[red], deleting[gray], return[gray])
ClusterStatus string `json:"clusterStatus"`
// elasticSearchStatus (green, yellow, orange, red, gray)
ElasticSearchStatus string `json:"elasticSearchStatus"`
}
type ElasticSearchVersion ¶
type GenericSwaggerError ¶
type GenericSwaggerError struct {
// contains filtered or unexported fields
}
GenericSwaggerError Provides access to the body, error and model on returned errors.
func (GenericSwaggerError) Body ¶
func (e GenericSwaggerError) Body() []byte
Body returns the raw bytes of the response
func (GenericSwaggerError) Error ¶
func (e GenericSwaggerError) Error() string
Error returns non-empty string if there was an error.
func (GenericSwaggerError) Model ¶
func (e GenericSwaggerError) Model() interface{}
Model returns the unpacked model of the error
type GetClusterIndicesStatusResponseVo ¶
type GetClusterIndicesStatusResponseVo struct {
CurrentPage int32 `json:"currentPage,omitempty"`
IndiceInfoList []CatIndice `json:"indiceInfoList,omitempty"`
IsPaged bool `json:"isPaged,omitempty"`
PageSize int32 `json:"pageSize,omitempty"`
TotalCount int32 `json:"totalCount,omitempty"`
TotalPage int32 `json:"totalPage,omitempty"`
}
type GetClusterRequest ¶
type GetClusterStatusResponseVo ¶
type GetClusterStatusResponseVo struct {
DocsCount string `json:"docsCount,omitempty"`
IndicesCount string `json:"indicesCount,omitempty"`
SegmentsCount string `json:"segmentsCount,omitempty"`
ShardCount string `json:"shardCount,omitempty"`
Status string `json:"status,omitempty"`
StoreSizeInUsed string `json:"storeSizeInUsed,omitempty"`
}
type GetElasticSearchVersionListResponseVo ¶
type GetElasticSearchVersionListResponseVo struct {
ElasticSearchVersionList []ElasticSearchVersion `json:"elasticSearchVersionList,omitempty"`
}
type GetImportHistoryListResponseVo ¶
type GetImportHistoryListResponseVo struct {
CurrentPage int32 `json:"currentPage,omitempty"`
ImportHistoryList []ImportHistoryVo `json:"importHistoryList,omitempty"`
IsFirst bool `json:"isFirst,omitempty"`
IsLast bool `json:"isLast,omitempty"`
PageSize int32 `json:"pageSize,omitempty"`
TotalCount int64 `json:"totalCount,omitempty"`
TotalPage int32 `json:"totalPage,omitempty"`
}
type GetObjectStorageBucketListResponseVo ¶
type GetObjectStorageBucketListResponseVo struct {
BucketList []BucketInfo `json:"bucketList,omitempty"`
}
type GetOpenApiAccessControlGroupRuleListResponseVo ¶
type GetOpenApiAccessControlGroupRuleListResponseVo struct {
InboundAcgRules []AcgRuleResponseDetailVo `json:"inboundAcgRules,omitempty"`
OutboundAcgRules []AcgRuleResponseDetailVo `json:"outboundAcgRules,omitempty"`
}
type GetOpenApiAcgInfoList ¶
type GetOpenApiAcgInfoList struct {
DataNodeAcgRule *GetOpenApiAccessControlGroupRuleListResponseVo `json:"dataNodeAcgRule,omitempty"`
ManagerNodeAcgRule *GetOpenApiAccessControlGroupRuleListResponseVo `json:"managerNodeAcgRule,omitempty"`
MasterNodeAcgRule *GetOpenApiAccessControlGroupRuleListResponseVo `json:"masterNodeAcgRule,omitempty"`
}
type GetOpenApiDashboardInformationResponseVo ¶
type GetOpenApiDashboardInformationResponseVo struct {
ClusterIndicesStatus *GetClusterIndicesStatusResponseVo `json:"clusterIndicesStatus,omitempty"`
ClusterStatus *GetClusterStatusResponseVo `json:"clusterStatus,omitempty"`
}
type GetOpenApiHwProductListResponseVo ¶
type GetOpenApiHwProductListResponseVo struct {
ProductList []OpenApiHwProductVo `json:"productList,omitempty"`
}
type GetOpenApiLoginKeyListResponseVo ¶
type GetOpenApiLoginKeyListResponseVo struct {
LoginKeyList []OpenApiLoginKeyVo `json:"loginKeyList,omitempty"`
TotalRows int32 `json:"totalRows,omitempty"`
}
type GetOpenApiOsProductListResponseVo ¶
type GetOpenApiOsProductListResponseVo struct {
ProductList []OpenApiOsProductVo `json:"productList,omitempty"`
}
type GetOpenApiServiceGroupResponseVo ¶
type GetOpenApiServiceGroupResponseVo struct {
ComputeList []OpenApiGetComputeInstanceListResponseDetailVo `json:"computeList,omitempty"`
ContractNo int32 `json:"contractNo,omitempty"`
CreatedDate *DateTimeVo `json:"createdDate,omitempty"`
ProductCode string `json:"productCode,omitempty"`
RegionNo int32 `json:"regionNo,omitempty"`
ServiceGroupInstanceNo int32 `json:"serviceGroupInstanceNo,omitempty"`
ServiceGroupInstanceTypeCode string `json:"serviceGroupInstanceTypeCode,omitempty"`
ServiceGroupName string `json:"serviceGroupName,omitempty"`
StatusCode string `json:"statusCode,omitempty"`
VpcNo int32 `json:"vpcNo,omitempty"`
}
type GetOsMonitoringData ¶
type GetSnapshotSchedulingHistoryResponseVo ¶
type GetSnapshotSchedulingHistoryResponseVo struct {
CurrentPage int32 `json:"currentPage,omitempty"`
IsFirst bool `json:"isFirst,omitempty"`
IsLast bool `json:"isLast,omitempty"`
PageSize int32 `json:"pageSize,omitempty"`
SnapshotSchedulingHistoryList []SnapshotSchedulingHistoryResponseVo `json:"snapshotSchedulingHistoryList,omitempty"`
TotalCount int64 `json:"totalCount,omitempty"`
TotalPage int32 `json:"totalPage,omitempty"`
}
type GetSubnetList ¶
type GetVpcConfigListResponseDetailVo ¶
type GetVpcConfigListResponseDetailVo struct {
CreatedDate *DateTimeVo `json:"createdDate,omitempty"`
Ipv4Cidr string `json:"ipv4Cidr,omitempty"`
Permission string `json:"permission,omitempty"`
RegionNo string `json:"regionNo,omitempty"`
StatusCode string `json:"statusCode,omitempty"`
VpcName string `json:"vpcName,omitempty"`
VpcNo int32 `json:"vpcNo,omitempty"`
}
type GetVpcConfigListResponseVo ¶
type GetVpcConfigListResponseVo struct {
Content []GetVpcConfigListResponseDetailVo `json:"content,omitempty"`
}
type GetVpcSubnetListResponseVo ¶
type GetVpcSubnetListResponseVo struct {
Content []VpcSubnetListResponseDetailVo `json:"content,omitempty"`
}
type ImportHistoryVo ¶
type ImportHistoryVo struct {
ActionEndDate string `json:"actionEndDate,omitempty"`
ActionStartDate string `json:"actionStartDate,omitempty"`
BucketName string `json:"bucketName,omitempty"`
ClusterName string `json:"clusterName,omitempty"`
ImportStatus string `json:"importStatus,omitempty"`
ObjectKey string `json:"objectKey,omitempty"`
Progress int32 `json:"progress,omitempty"`
ServiceGroupInstanceNo int32 `json:"serviceGroupInstanceNo,omitempty"`
}
type MetricInfoResponseVo ¶
type MetricInfoResponseVo struct {
Aggregation string `json:"aggregation,omitempty"`
Dimensions *DimensionsVo `json:"dimensions,omitempty"`
Dps [][]interface{} `json:"dps,omitempty"`
GraphName string `json:"graphName,omitempty"`
Interval string `json:"interval,omitempty"`
Metric string `json:"metric,omitempty"`
ProductName string `json:"productName,omitempty"`
}
type NodeProduct ¶
type OpenApiGetClusterInfoListResponseVo ¶
type OpenApiGetClusterInfoListResponseVo struct {
AllowedClusters []*AllowedClusterInfo `json:"allowedClusters,omitempty"`
CurrentPage int32 `json:"currentPage,omitempty"`
DisallowedClusters []*DisallowedClusterInfo `json:"disallowedClusters,omitempty"`
IsFirst bool `json:"isFirst,omitempty"`
IsLast bool `json:"isLast,omitempty"`
PageSize int32 `json:"pageSize,omitempty"`
TotalCount int64 `json:"totalCount,omitempty"`
TotalPage int32 `json:"totalPage,omitempty"`
}
type OpenApiGetClusterInfoResponseVo ¶ added in v1.5.0
type OpenApiGetClusterInfoResponseVo struct {
ClusterName *string `json:"clusterName,omitempty"`
ClusterStatus *string `json:"clusterStatus,omitempty"`
ApplicationVersionCode *string `json:"applicationVersionCode,omitempty"`
LoginKeyName *string `json:"loginKeyName,omitempty"`
ServiceGroupInstanceNo *string `json:"serviceGroupInstanceNo,omitempty"`
SoftwareProductCode *string `json:"softwareProductCode,omitempty"`
VpcNo *int32 `json:"vpcNo,omitempty"`
DataNodeCount *int32 `json:"dataNodeCount,omitempty"`
DataNodeSubnetNo *int32 `json:"dataNodeSubnetNo,omitempty"`
DataNodeProductCode *string `json:"dataNodeProductCode,omitempty"`
ManagerNodeCount *int32 `json:"managerNodeCount,omitempty"`
ManagerNodeSubnetNo *int32 `json:"managerNodeSubnetNo,omitempty"`
ManagerNodeProductCode *string `json:"managerNodeProductCode,omitempty"`
MasterNodeCount *int32 `json:"masterNodeCount,omitempty"`
MasterNodeSubnetNo *int32 `json:"masterNodeSubnetNo,omitempty"`
MasterNodeProductCode *string `json:"masterNodeProductCode,omitempty"`
}
type OpenApiGetComputeInstanceListResponseDetailVo ¶
type OpenApiGetComputeInstanceListResponseDetailVo struct {
ComputeInstanceNo int32 `json:"computeInstanceNo,omitempty"`
ComputeInstanceProductCode string `json:"computeInstanceProductCode,omitempty"`
ComputeInstanceStatus string `json:"computeInstanceStatus,omitempty"`
CpuCount int32 `json:"cpuCount,omitempty"`
CreatedYmdt *DateTimeVo `json:"createdYmdt,omitempty"`
HostName string `json:"hostName,omitempty"`
MacAddress string `json:"macAddress,omitempty"`
MemorySize int64 `json:"memorySize,omitempty"`
NodeRoleCode string `json:"nodeRoleCode,omitempty"`
OperationYmdt *DateTimeVo `json:"operationYmdt,omitempty"`
OsInfo string `json:"osInfo,omitempty"`
PrivateIp string `json:"privateIp,omitempty"`
RegionCode string `json:"regionCode,omitempty"`
RegionName string `json:"regionName,omitempty"`
RegionNo string `json:"regionNo,omitempty"`
SelfManaged bool `json:"selfManaged,omitempty"`
ServiceGroupInstanceNo int32 `json:"serviceGroupInstanceNo,omitempty"`
SubnetName string `json:"subnetName,omitempty"`
SubnetNo int32 `json:"subnetNo,omitempty"`
Uuid string `json:"uuid,omitempty"`
VpcName string `json:"vpcName,omitempty"`
VpcNo int32 `json:"vpcNo,omitempty"`
ZoneName string `json:"zoneName,omitempty"`
ZoneNo int32 `json:"zoneNo,omitempty"`
}
type OpenApiHwProductVo ¶
type OpenApiHwProductVo struct {
CpuCount string `json:"cpuCount,omitempty"`
DiskType2Code string `json:"diskType2Code,omitempty"`
InfraResourceTypeCode string `json:"infraResourceTypeCode,omitempty"`
MemorySize int64 `json:"memorySize,omitempty"`
ProductCode string `json:"productCode,omitempty"`
ProductEnglishDesc string `json:"productEnglishDesc,omitempty"`
ProductName string `json:"productName,omitempty"`
ProductType2Code string `json:"productType2Code,omitempty"`
}
type OpenApiLoginKeyVo ¶
type OpenApiLoginKeyVo struct {
KeyName string `json:"keyName,omitempty"`
}
type OpenApiOsProductVo ¶
type OpenApiOsProductVo struct {
InfraResourceTypeCode string `json:"infraResourceTypeCode,omitempty"`
ProductCode string `json:"productCode,omitempty"`
ProductEnglishDesc string `json:"productEnglishDesc,omitempty"`
ProductName string `json:"productName,omitempty"`
ProductType2Code string `json:"productType2Code,omitempty"`
SoftwareTypeCode string `json:"softwareTypeCode,omitempty"`
}
type QueryMultipleDataResponseVo ¶
type QueryMultipleDataResponseVo struct {
Data []MetricInfoResponseVo `json:"data,omitempty"`
}
type ResetKibanaPassword ¶
type ResetKibanaPassword struct {
KibanaUserPassword string `json:"kibanaUserPassword"`
}
type ResponseVoBoolean ¶
type ResponseVoCreateClusterResponseVo ¶
type ResponseVoCreateClusterResponseVo struct {
Code int32 `json:"code,omitempty"`
Message string `json:"message,omitempty"`
RequestId string `json:"requestId,omitempty"`
Result *CreateClusterResponseVo `json:"result,omitempty"`
}
type ResponseVoGetElasticSearchVersionListResponseVo ¶
type ResponseVoGetElasticSearchVersionListResponseVo struct {
Code int32 `json:"code,omitempty"`
Message string `json:"message,omitempty"`
RequestId string `json:"requestId,omitempty"`
Result *GetElasticSearchVersionListResponseVo `json:"result,omitempty"`
}
type ResponseVoGetImportHistoryListResponseVo ¶
type ResponseVoGetImportHistoryListResponseVo struct {
Code int32 `json:"code,omitempty"`
Message string `json:"message,omitempty"`
RequestId string `json:"requestId,omitempty"`
Result *GetImportHistoryListResponseVo `json:"result,omitempty"`
}
type ResponseVoGetObjectStorageBucketListResponseVo ¶
type ResponseVoGetObjectStorageBucketListResponseVo struct {
Code int32 `json:"code,omitempty"`
Message string `json:"message,omitempty"`
RequestId string `json:"requestId,omitempty"`
Result *GetObjectStorageBucketListResponseVo `json:"result,omitempty"`
}
type ResponseVoGetOpenApiAcgInfoList ¶
type ResponseVoGetOpenApiAcgInfoList struct {
Code int32 `json:"code,omitempty"`
Message string `json:"message,omitempty"`
RequestId string `json:"requestId,omitempty"`
Result *GetOpenApiAcgInfoList `json:"result,omitempty"`
}
type ResponseVoGetOpenApiDashboardInformationResponseVo ¶
type ResponseVoGetOpenApiDashboardInformationResponseVo struct {
Code int32 `json:"code,omitempty"`
Message string `json:"message,omitempty"`
RequestId string `json:"requestId,omitempty"`
Result *GetOpenApiDashboardInformationResponseVo `json:"result,omitempty"`
}
type ResponseVoGetOpenApiHwProductListResponseVo ¶
type ResponseVoGetOpenApiHwProductListResponseVo struct {
Code int32 `json:"code,omitempty"`
Message string `json:"message,omitempty"`
RequestId string `json:"requestId,omitempty"`
Result *GetOpenApiHwProductListResponseVo `json:"result,omitempty"`
}
type ResponseVoGetOpenApiLoginKeyListResponseVo ¶
type ResponseVoGetOpenApiLoginKeyListResponseVo struct {
Code int32 `json:"code,omitempty"`
Message string `json:"message,omitempty"`
RequestId string `json:"requestId,omitempty"`
Result *GetOpenApiLoginKeyListResponseVo `json:"result,omitempty"`
}
type ResponseVoGetOpenApiOsProductListResponseVo ¶
type ResponseVoGetOpenApiOsProductListResponseVo struct {
Code int32 `json:"code,omitempty"`
Message string `json:"message,omitempty"`
RequestId string `json:"requestId,omitempty"`
Result *GetOpenApiOsProductListResponseVo `json:"result,omitempty"`
}
type ResponseVoGetOpenApiServiceGroupResponseVo ¶
type ResponseVoGetOpenApiServiceGroupResponseVo struct {
Code int32 `json:"code,omitempty"`
Message string `json:"message,omitempty"`
RequestId string `json:"requestId,omitempty"`
Result *GetOpenApiServiceGroupResponseVo `json:"result,omitempty"`
}
type ResponseVoGetSnapshotSchedulingHistoryResponseVo ¶
type ResponseVoGetSnapshotSchedulingHistoryResponseVo struct {
Code int32 `json:"code,omitempty"`
Message string `json:"message,omitempty"`
RequestId string `json:"requestId,omitempty"`
Result *GetSnapshotSchedulingHistoryResponseVo `json:"result,omitempty"`
}
type ResponseVoGetVpcConfigListResponseVo ¶
type ResponseVoGetVpcConfigListResponseVo struct {
Code int32 `json:"code,omitempty"`
Message string `json:"message,omitempty"`
RequestId string `json:"requestId,omitempty"`
Result *GetVpcConfigListResponseVo `json:"result,omitempty"`
}
type ResponseVoGetVpcSubnetListResponseVo ¶
type ResponseVoGetVpcSubnetListResponseVo struct {
Code int32 `json:"code,omitempty"`
Message string `json:"message,omitempty"`
RequestId string `json:"requestId,omitempty"`
Result *GetVpcSubnetListResponseVo `json:"result,omitempty"`
}
type ResponseVoOpenApiGetClusterInfoListResponseVo ¶
type ResponseVoOpenApiGetClusterInfoListResponseVo struct {
Code int32 `json:"code,omitempty"`
Message string `json:"message,omitempty"`
RequestId string `json:"requestId,omitempty"`
Result *OpenApiGetClusterInfoListResponseVo `json:"result,omitempty"`
}
type ResponseVoOpenApiGetClusterInfoResponseVo ¶ added in v1.5.0
type ResponseVoOpenApiGetClusterInfoResponseVo struct {
Code int32 `json:"code,omitempty"`
Message string `json:"message,omitempty"`
RequestId string `json:"requestId,omitempty"`
Result *OpenApiGetClusterInfoResponseVo `json:"result,omitempty"`
}
type ResponseVoQueryMultipleDataResponseVo ¶
type ResponseVoQueryMultipleDataResponseVo struct {
Code int32 `json:"code,omitempty"`
Message string `json:"message,omitempty"`
RequestId string `json:"requestId,omitempty"`
Result *QueryMultipleDataResponseVo `json:"result,omitempty"`
}
type ResponseVoSnapshotHistoryListResponseVo ¶
type ResponseVoSnapshotHistoryListResponseVo struct {
Code int32 `json:"code,omitempty"`
Message string `json:"message,omitempty"`
RequestId string `json:"requestId,omitempty"`
Result *SnapshotHistoryListResponseVo `json:"result,omitempty"`
}
type SetSnapshotScheduling ¶
type SnapshotHistoryListResponseVo ¶
type SnapshotHistoryListResponseVo struct {
CurrentPage int32 `json:"currentPage,omitempty"`
IsFirst bool `json:"isFirst,omitempty"`
IsLast bool `json:"isLast,omitempty"`
PageSize int32 `json:"pageSize,omitempty"`
SnapshotHistoryResponseList []SnapshotHistoryResponseVo `json:"snapshotHistoryResponseList,omitempty"`
TotalCount int64 `json:"totalCount,omitempty"`
TotalPage int32 `json:"totalPage,omitempty"`
}
type SnapshotHistoryResponseVo ¶
type SnapshotHistoryResponseVo struct {
ActionDate string `json:"actionDate,omitempty"`
BucketName string `json:"bucketName,omitempty"`
ClusterName string `json:"clusterName,omitempty"`
Duration string `json:"duration,omitempty"`
HasErrorLog bool `json:"hasErrorLog,omitempty"`
Idx int32 `json:"idx,omitempty"`
MemberNo string `json:"memberNo,omitempty"`
Message string `json:"message,omitempty"`
RequestType string `json:"requestType,omitempty"`
ServiceGroupInstanceNo int32 `json:"serviceGroupInstanceNo,omitempty"`
SnapshotName string `json:"snapshotName,omitempty"`
}
type SnapshotSchedulingHistoryResponseVo ¶
type SnapshotSchedulingHistoryResponseVo struct {
BucketName string `json:"bucketName,omitempty"`
SnapshotName string `json:"snapshotName,omitempty"`
SnapshotSchedulingConfigSetUpDate string `json:"snapshotSchedulingConfigSetUpDate,omitempty"`
SnapshotSchedulingSetUpDay string `json:"snapshotSchedulingSetUpDay,omitempty"`
SnapshotSchedulingSetUpTime string `json:"snapshotSchedulingSetUpTime,omitempty"`
SnapshotSchedulingStatus string `json:"snapshotSchedulingStatus,omitempty"`
}
type V1ApiService ¶
type V1ApiService service
func (*V1ApiService) ClusterChangeCountOfDataNodeServiceGroupInstanceNoPost ¶
func (a *V1ApiService) ClusterChangeCountOfDataNodeServiceGroupInstanceNoPost(ctx context.Context, changeCountOfDataNode AddNodesInCluster, serviceGroupInstanceNo string) (ResponseVoBoolean, *http.Response, error)
V1ApiService
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param changeCountOfDataNode 데이터 노드 추가 파라미터
- @param serviceGroupInstanceNo serviceGroupInstanceNo
@return ResponseVoBoolean
func (*V1ApiService) ClusterCreateElasticsearchClusterPost ¶
func (a *V1ApiService) ClusterCreateElasticsearchClusterPost(ctx context.Context, createCluster *CreateCluster) (ResponseVoCreateClusterResponseVo, *http.Response, error)
V1ApiService
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param createCluster 클러스터 생성 파라미터
@return ResponseVoCreateClusterResponseVo
func (*V1ApiService) ClusterDeleteElasticsearchClusterServiceGroupInstanceNoDelete ¶
func (a *V1ApiService) ClusterDeleteElasticsearchClusterServiceGroupInstanceNoDelete(ctx context.Context, serviceGroupInstanceNo *string) (ResponseVoBoolean, *http.Response, error)
V1ApiService
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param serviceGroupInstanceNo serviceGroupInstanceNo
@return ResponseVoBoolean
func (*V1ApiService) ClusterGetAcgInfoListServiceGroupInstanceNoGet ¶
func (a *V1ApiService) ClusterGetAcgInfoListServiceGroupInstanceNoGet(ctx context.Context, serviceGroupInstanceNo string) (ResponseVoGetOpenApiAcgInfoList, *http.Response, error)
V1ApiService
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param serviceGroupInstanceNo serviceGroupInstanceNo
@return ResponseVoGetOpenApiAcgInfoList
func (*V1ApiService) ClusterGetClusterDataNodeListServiceGroupInstanceNoGet ¶
func (a *V1ApiService) ClusterGetClusterDataNodeListServiceGroupInstanceNoGet(ctx context.Context, serviceGroupInstanceNo string) (ResponseVoGetOpenApiServiceGroupResponseVo, *http.Response, error)
V1ApiService
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param serviceGroupInstanceNo serviceGroupInstanceNo
@return ResponseVoGetOpenApiServiceGroupResponseVo
func (*V1ApiService) ClusterGetClusterInfoGet ¶ added in v1.5.0
func (a *V1ApiService) ClusterGetClusterInfoGet(ctx context.Context, serviceGroupInstanceNo *string) (ResponseVoOpenApiGetClusterInfoResponseVo, *http.Response, error)
V1ApiService
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param serviceGroupInstanceNo serviceGroupInstanceNo
@return ResponseVoOpenApiGetClusterInfoResponseVo
func (*V1ApiService) ClusterGetClusterInfoListPost ¶
func (a *V1ApiService) ClusterGetClusterInfoListPost(ctx context.Context, clusterInfoRequest *GetClusterRequest) (ResponseVoOpenApiGetClusterInfoListResponseVo, *http.Response, error)
V1ApiService
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param clusterInfoRequest 클러스터 조회 시 사용되는 파라미터
@return ResponseVoOpenApiGetClusterInfoListResponseVo
func (*V1ApiService) ClusterGetElasticsearchVersionListGet ¶
func (a *V1ApiService) ClusterGetElasticsearchVersionListGet(ctx context.Context) (ResponseVoGetElasticSearchVersionListResponseVo, *http.Response, error)
V1ApiService
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@return ResponseVoGetElasticSearchVersionListResponseVo
func (*V1ApiService) ClusterGetLoginKeyListGet ¶
func (a *V1ApiService) ClusterGetLoginKeyListGet(ctx context.Context) (ResponseVoGetOpenApiLoginKeyListResponseVo, *http.Response, error)
V1ApiService
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@return ResponseVoGetOpenApiLoginKeyListResponseVo
func (*V1ApiService) ClusterGetNodeProductListPost ¶
func (a *V1ApiService) ClusterGetNodeProductListPost(ctx context.Context, getNodeProductList NodeProduct) (ResponseVoGetOpenApiHwProductListResponseVo, *http.Response, error)
V1ApiService
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param getNodeProductList HW 상품 스펙 조회 파라미터
@return ResponseVoGetOpenApiHwProductListResponseVo
func (*V1ApiService) ClusterGetOsProductListGet ¶
func (a *V1ApiService) ClusterGetOsProductListGet(ctx context.Context) (ResponseVoGetOpenApiOsProductListResponseVo, *http.Response, error)
V1ApiService
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@return ResponseVoGetOpenApiOsProductListResponseVo
func (*V1ApiService) ClusterGetSubnetListPost ¶
func (a *V1ApiService) ClusterGetSubnetListPost(ctx context.Context, getSubnetList GetSubnetList) (ResponseVoGetVpcSubnetListResponseVo, *http.Response, error)
V1ApiService
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param getSubnetList Subnet 목록 조회
@return ResponseVoGetVpcSubnetListResponseVo
func (*V1ApiService) ClusterGetVpcListGet ¶
func (a *V1ApiService) ClusterGetVpcListGet(ctx context.Context) (ResponseVoGetVpcConfigListResponseVo, *http.Response, error)
V1ApiService
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
@return ResponseVoGetVpcConfigListResponseVo
func (*V1ApiService) ClusterResetKibanaPasswordServiceGroupInstanceNoPost ¶
func (a *V1ApiService) ClusterResetKibanaPasswordServiceGroupInstanceNoPost(ctx context.Context, kibanaPassword ResetKibanaPassword, serviceGroupInstanceNo string) (ResponseVoBoolean, *http.Response, error)
V1ApiService
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param kibanaPassword 키바나 패스워드 변경
- @param serviceGroupInstanceNo serviceGroupInstanceNo
@return ResponseVoBoolean
func (*V1ApiService) ClusterRestartElasticsearchClusterServiceGroupInstanceNoGet ¶
func (a *V1ApiService) ClusterRestartElasticsearchClusterServiceGroupInstanceNoGet(ctx context.Context, serviceGroupInstanceNo string) (ResponseVoBoolean, *http.Response, error)
V1ApiService
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param serviceGroupInstanceNo serviceGroupInstanceNo
@return ResponseVoBoolean
func (*V1ApiService) DashboardGetDashboardInformationServiceGroupInstanceNoGet ¶
func (a *V1ApiService) DashboardGetDashboardInformationServiceGroupInstanceNoGet(ctx context.Context, serviceGroupInstanceNo string, localVarOptionals *V1ApiDashboardGetDashboardInformationServiceGroupInstanceNoGetOpts) (ResponseVoGetOpenApiDashboardInformationResponseVo, *http.Response, error)
func (*V1ApiService) ImportCreateDataImportJobServiceGroupInstanceNoPost ¶
func (a *V1ApiService) ImportCreateDataImportJobServiceGroupInstanceNoPost(ctx context.Context, createImportJob CreateImportJob, serviceGroupInstanceNo string) (ResponseVoBoolean, *http.Response, error)
V1ApiService
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param createImportJob Create Import Job 파라미터
- @param serviceGroupInstanceNo serviceGroupInstanceNo
@return ResponseVoBoolean
func (*V1ApiService) ImportGetBucketListServiceGroupInstanceNoGet ¶
func (a *V1ApiService) ImportGetBucketListServiceGroupInstanceNoGet(ctx context.Context, serviceGroupInstanceNo string) (ResponseVoBoolean, *http.Response, error)
V1ApiService
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param serviceGroupInstanceNo serviceGroupInstanceNo
@return ResponseVoBoolean
func (*V1ApiService) ImportGetDataImportHistoryServiceGroupInstanceNoGet ¶
func (a *V1ApiService) ImportGetDataImportHistoryServiceGroupInstanceNoGet(ctx context.Context, serviceGroupInstanceNo string, localVarOptionals *V1ApiImportGetDataImportHistoryServiceGroupInstanceNoGetOpts) (ResponseVoGetImportHistoryListResponseVo, *http.Response, error)
func (*V1ApiService) ImportStopDataImportJobServiceGroupInstanceNoGet ¶
func (a *V1ApiService) ImportStopDataImportJobServiceGroupInstanceNoGet(ctx context.Context, serviceGroupInstanceNo string) (ResponseVoBoolean, *http.Response, error)
V1ApiService
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param serviceGroupInstanceNo serviceGroupInstanceNo
@return ResponseVoBoolean
func (*V1ApiService) MonitoringGetElasticsearchMonitoringDataServiceGroupInstanceNoPost ¶
func (a *V1ApiService) MonitoringGetElasticsearchMonitoringDataServiceGroupInstanceNoPost(ctx context.Context, getElasticsearchMonitoringData GetElasticsearchMonitoringData, serviceGroupInstanceNo string) (ResponseVoQueryMultipleDataResponseVo, *http.Response, error)
V1ApiService
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param getElasticsearchMonitoringData ES 모니터링 데이터 조회 파라미터
- @param serviceGroupInstanceNo serviceGroupInstanceNo
@return ResponseVoQueryMultipleDataResponseVo
func (*V1ApiService) MonitoringGetOsMonitoringDataServiceGroupInstanceNoPost ¶
func (a *V1ApiService) MonitoringGetOsMonitoringDataServiceGroupInstanceNoPost(ctx context.Context, getOsMonitoringData GetOsMonitoringData, serviceGroupInstanceNo string) (ResponseVoQueryMultipleDataResponseVo, *http.Response, error)
V1ApiService
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param getOsMonitoringData OS 모니터링 데이터 조회 파라미터
- @param serviceGroupInstanceNo serviceGroupInstanceNo
@return ResponseVoQueryMultipleDataResponseVo
func (*V1ApiService) SnapshotCreateSnapshotServiceGroupInstanceNoPost ¶
func (a *V1ApiService) SnapshotCreateSnapshotServiceGroupInstanceNoPost(ctx context.Context, createSnapshot CreateSnapshot, serviceGroupInstanceNo string) (ResponseVoBoolean, *http.Response, error)
V1ApiService
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param createSnapshot Snapshot 생성 파라미터
- @param serviceGroupInstanceNo serviceGroupInstanceNo
@return ResponseVoBoolean
func (*V1ApiService) SnapshotGetBucketListServiceGroupInstanceNoGet ¶
func (a *V1ApiService) SnapshotGetBucketListServiceGroupInstanceNoGet(ctx context.Context, serviceGroupInstanceNo string) (ResponseVoGetObjectStorageBucketListResponseVo, *http.Response, error)
V1ApiService
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param serviceGroupInstanceNo serviceGroupInstanceNo
@return ResponseVoGetObjectStorageBucketListResponseVo
func (*V1ApiService) SnapshotGetSnapshotHistoryServiceGroupInstanceNoGet ¶
func (a *V1ApiService) SnapshotGetSnapshotHistoryServiceGroupInstanceNoGet(ctx context.Context, serviceGroupInstanceNo string, localVarOptionals *V1ApiSnapshotGetSnapshotHistoryServiceGroupInstanceNoGetOpts) (ResponseVoSnapshotHistoryListResponseVo, *http.Response, error)
func (*V1ApiService) SnapshotGetSnapshotSchedulingHistoryServiceGroupInstanceNoPost ¶
func (a *V1ApiService) SnapshotGetSnapshotSchedulingHistoryServiceGroupInstanceNoPost(ctx context.Context, getSnapshotSchedulingHistory GetSnapshotSchedulingHistory, serviceGroupInstanceNo string) (ResponseVoGetSnapshotSchedulingHistoryResponseVo, *http.Response, error)
V1ApiService
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param getSnapshotSchedulingHistory Snapshot Scheduling 이력 조회
- @param serviceGroupInstanceNo serviceGroupInstanceNo
@return ResponseVoGetSnapshotSchedulingHistoryResponseVo
func (*V1ApiService) SnapshotReleaseSnapshotSchedulingServiceGroupInstanceNoGet ¶
func (a *V1ApiService) SnapshotReleaseSnapshotSchedulingServiceGroupInstanceNoGet(ctx context.Context, serviceGroupInstanceNo string) (ResponseVoBoolean, *http.Response, error)
V1ApiService
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param serviceGroupInstanceNo serviceGroupInstanceNo
@return ResponseVoBoolean
func (*V1ApiService) SnapshotSetSnapshotSchedulingServiceGroupInstanceNoPost ¶
func (a *V1ApiService) SnapshotSetSnapshotSchedulingServiceGroupInstanceNoPost(ctx context.Context, setSnapshotScheduling SetSnapshotScheduling, serviceGroupInstanceNo string) (ResponseVoBoolean, *http.Response, error)
V1ApiService
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param setSnapshotScheduling Snapshot Scheduling 설정
- @param serviceGroupInstanceNo serviceGroupInstanceNo
@return ResponseVoBoolean
func (*V1ApiService) SnapshotUpdateAPIAuthenticationKeyServiceGroupInstanceNoPost ¶
func (a *V1ApiService) SnapshotUpdateAPIAuthenticationKeyServiceGroupInstanceNoPost(ctx context.Context, updateAPIAuthenticationKey UpdateApiAuthenticationKey, serviceGroupInstanceNo string) (ResponseVoBoolean, *http.Response, error)
V1ApiService
- @param ctx context.Context - for authentication, logging, cancellation, deadlines, tracing, etc. Passed from http.Request or context.Background().
- @param updateAPIAuthenticationKey API 인증키 설정 파라미터
- @param serviceGroupInstanceNo serviceGroupInstanceNo
@return ResponseVoBoolean
type VpcSubnetListResponseDetailVo ¶
type VpcSubnetListResponseDetailVo struct {
IsPublic bool `json:"isPublic,omitempty"`
Permission string `json:"permission,omitempty"`
StatusCode string `json:"statusCode,omitempty"`
Subnet string `json:"subnet,omitempty"`
SubnetName string `json:"subnetName,omitempty"`
SubnetNo int32 `json:"subnetNo,omitempty"`
VpcName string `json:"vpcName,omitempty"`
VpcNo int32 `json:"vpcNo,omitempty"`
ZoneName string `json:"zoneName,omitempty"`
ZoneNo int32 `json:"zoneNo,omitempty"`
}
Source Files
¶
- acg_rule_response_detail_vo.go
- add_nodes_in_cluster.go
- allowed_cluster_info.go
- api_client.go
- api_response.go
- bucket_info.go
- cat_indice.go
- configuration.go
- create_cluster.go
- create_cluster_response_vo.go
- create_import_job.go
- create_snapshot.go
- date_time_vo.go
- dimensions_vo.go
- disallowed_cluster_info.go
- elastic_search_version.go
- get_cluster_indices_status_response_vo.go
- get_cluster_request.go
- get_cluster_status_response_vo.go
- get_elastic_search_version_list_response_vo.go
- get_elasticsearch_monitoring_data.go
- get_import_history_list_response_vo.go
- get_object_storage_bucket_list_response_vo.go
- get_open_api_access_control_group_rule_list_response_vo.go
- get_open_api_acg_info_list.go
- get_open_api_dashboard_information_response_vo.go
- get_open_api_hw_product_list_response_vo.go
- get_open_api_login_key_list_response_vo.go
- get_open_api_os_product_list_response_vo.go
- get_open_api_service_group_response_vo.go
- get_os_monitoring_data.go
- get_snapshot_scheduling_history.go
- get_snapshot_scheduling_history_response_vo.go
- get_subnet_list.go
- get_vpc_config_list_response_detail_vo.go
- get_vpc_config_list_response_vo.go
- get_vpc_subnet_list_response_vo.go
- import_history_vo.go
- metric_info_response_vo.go
- node_product.go
- open_api_get_cluster_info_list_response_vo.go
- open_api_get_cluster_info_response_vo.go
- open_api_get_compute_instance_list_response_detail_vo.go
- open_api_hw_product_vo.go
- open_api_login_key_vo.go
- open_api_os_product_vo.go
- query_multiple_data_response_vo.go
- reset_kibana_password.go
- response_vo_boolean.go
- response_vo_create_cluster_response_vo.go
- response_vo_get_elastic_search_version_list_response_vo.go
- response_vo_get_import_history_list_response_vo.go
- response_vo_get_object_storage_bucket_list_response_vo.go
- response_vo_get_open_api_acg_info_list.go
- response_vo_get_open_api_dashboard_information_response_vo.go
- response_vo_get_open_api_hw_product_list_response_vo.go
- response_vo_get_open_api_login_key_list_response_vo.go
- response_vo_get_open_api_os_product_list_response_vo.go
- response_vo_get_open_api_service_group_response_vo.go
- response_vo_get_snapshot_scheduling_history_response_vo.go
- response_vo_get_vpc_config_list_response_vo.go
- response_vo_get_vpc_subnet_list_response_vo.go
- response_vo_open_api_get_cluster_info_list_response_vo.go
- response_vo_open_api_get_cluster_info_response_vo.go
- response_vo_query_multiple_data_response_vo.go
- response_vo_snapshot_history_list_response_vo.go
- set_snapshot_scheduling.go
- snapshot_history_list_response_vo.go
- snapshot_history_response_vo.go
- snapshot_scheduling_history_response_vo.go
- update_api_authentication_key.go
- v1_api.go
- vpc_subnet_list_response_detail_vo.go